pub enum Var {
ERROR,
Name(Token),
TableAccess(TableAccess),
}Expand description
Possible ways in which a variable can be referenced.
Variants
ERROR
This Var had a syntax error.
Name(Token)
A simple reference to the variable.
local _ = fooTableAccess(TableAccess)
A field accessed from a table.
local _ = t.fooTrait Implementations
impl Eq for Var
Sourceimpl Ord for Var
impl Ord for Var
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Var
impl PartialOrd for Var
Sourceimpl Print for Var
impl Print for Var
Sourcefn print_final_trivia(&self) -> String
fn print_final_trivia(&self) -> String
Prints only the very final trivia. Used for the default implementation of
Print::print, which just joins Print::print_without_final_trivia
and this function.Sourcefn print_without_final_trivia(&self) -> String
fn print_without_final_trivia(&self) -> String
Prints the whole token including all surrounding trivia, excluding the
very last trailing trivia.
impl StructuralPartialEq for Var