pub struct Block {
pub statements: Vec<(Pointer<Statement>, Option<Token>)>,
pub last_statement: Option<(Pointer<TerminationStatement>, Option<Token>)>,
}Expand description
A block of code that represents a single scope (and nested ones).
Fields
statements: Vec<(Pointer<Statement>, Option<Token>)>The tokens in the of this block only. Parent
blocks’ tokens won’t be included. The optional Token
is the optional semicolon after the statement.
last_statement: Option<(Pointer<TerminationStatement>, Option<Token>)>The last statement (aka termination statement)
of this scope. The optional Token is the optional semicolon after the
statement.
Implementations